import { Calendar, CalendarEvent, AttachmentRequest, Attachment, ChannelSendPolicy, ChatType, Chat, ChatMap, InternalMessage, Invite, Message, MessageAttachment, MessageAttachmentData, MessageStatus, AttachmentStatus, RoomInfo, SfuEvent, State, User, UserEmail, UserId, UserPassword, UserPmiSettings, UserNickname, UserSpecificChatInfo, ChatReceivePolicy, UserInfo, UserTimezone, UserHostKey, UserPhoneNumber, SignUpStatus, ChatMessagesCount, MessageAttachmentsSearchResult, MessageAttachmentMediaType, SortOrder, LoadBookmarkedMessagesResult, LoadMessagesWithMentionsResult } from "./constants";
import { RoomExtended } from "./room-extended";
import { SendingAttachmentsHandler } from "./sending-attachments-handler";
import { PrefixFunction, Verbosity } from "./logger";
import { ResetPasswordHandler } from "./reset-password-handler";
declare type NotifyUnion = InternalMessage | Message | MessageStatus | AttachmentStatus | Array<User> | Calendar | UserSpecificChatInfo | Invite | User | ChatMap | Chat | ArrayBuffer | CalendarEvent | Attachment | UserInfo;
export declare class SfuExtended {
    #private;
    constructor(logLevel?: Verbosity, prefix?: PrefixFunction, log?: any);
    connect(options: {
        url: string;
        username: UserId;
        password: string;
        nickname: UserNickname;
        timeout?: number;
        binaryChunkSize?: number;
        failedProbesThreshold?: number;
        pingInterval?: number;
    }): Promise<{
        username: UserId;
        email: UserEmail;
        nickname: UserNickname;
        pmi: string;
    }>;
    signUp(options: {
        url: string;
        timeout?: number;
        email: string;
        password: string;
    }): Promise<SignUpStatus>;
    resetPassword(options: {
        url: string;
        timeout?: number;
        email: string;
    }): Promise<ResetPasswordHandler>;
    removeUser(options: {
        url: string;
        timeout?: number;
        id: string;
    }): Promise<void>;
    sendMessage(msg: {
        body?: string;
        to?: string;
        parentId?: string;
        chatId: string;
        attachments?: Array<MessageAttachment>;
    }): Promise<MessageStatus>;
    getSendingAttachmentsHandler(attachments: Array<MessageAttachmentData>, messageId: string): SendingAttachmentsHandler;
    getMessageAttachment(attachment: AttachmentRequest): Promise<Attachment>;
    markMessageRead(msg: {
        id: string;
        chatId: string;
    }): Promise<UserSpecificChatInfo>;
    markMessageUnread(msg: {
        id: string;
        chatId: string;
    }): Promise<UserSpecificChatInfo>;
    getUserList(): Promise<User[]>;
    getUserCalendar(): Promise<Calendar>;
    getUserPmiSettings(): Promise<UserPmiSettings>;
    updateUserPmiSettings(settings: {
        allowJoinAtAnyTime: boolean;
        useMuteAudioOnJoin: boolean;
        useLocalAutoRecord: boolean;
        useAccessCode: boolean;
        useWaitingRoom: boolean;
        useOwnerVideo: boolean;
        useParticipantsVideo: boolean;
        accessCode: string;
    }): Promise<UserPmiSettings>;
    getUserInfo(): Promise<UserInfo>;
    changeUserEmail(email: UserEmail): Promise<void>;
    changeUserPassword(currentPassword: UserPassword, newPassword: UserPassword): Promise<void>;
    changeUserNickname(nickname: UserNickname): Promise<void>;
    changeUserPhoneNumber(phoneNumber: UserPhoneNumber): Promise<void>;
    changeUserHostKey(hostKey: UserHostKey): Promise<void>;
    changeUserTimezone(timezone: UserTimezone): Promise<void>;
    addCalendarEvent(event: {
        title: string;
        description: string;
        start: number;
        end: number;
        recurring: boolean;
        accessCode?: string;
        waitingRoom: boolean;
        usePMI: boolean;
        ownerVideo: boolean;
        participantVideo: boolean;
        allowJoinAtAnyTime: boolean;
        useMuteAudioOnJoin: boolean;
        useLocalAutoRecord: boolean;
    }): Promise<CalendarEvent>;
    removeCalendarEvent(event: {
        id: string;
    }): Promise<CalendarEvent>;
    updateCalendarEvent(event: {
        id: string;
        title: string;
        description: string;
        start: number;
        end: number;
        recurring: boolean;
        accessCode?: string;
        waitingRoom: boolean;
        usePMI: boolean;
        ownerVideo: boolean;
        participantVideo: boolean;
        allowJoinAtAnyTime: boolean;
        useMuteAudioOnJoin: boolean;
        useLocalAutoRecord: boolean;
    }): Promise<CalendarEvent>;
    getUserChats(): Promise<ChatMap>;
    getPublicChannels(): Promise<ChatMap>;
    loadChat(chat: {
        id: string;
    }): Promise<Chat>;
    loadChatMessages(params: {
        chatId: string;
        timeFrame?: {
            start: number;
            end: number;
            limit?: number;
        };
        boundaries?: {
            dateMark: number;
            lowerLimit: number;
            upperLimit: number;
        };
    }): Promise<Message[]>;
    searchChatMessages(params: {
        chatId: string;
        searchString: string;
        searchId?: string;
        limit?: number;
    }): Promise<Message[]>;
    getChatMessagesCount(chat: {
        id: string;
    }): Promise<ChatMessagesCount>;
    searchMessageAttachments(params: {
        chatId?: string;
        attachmentsType?: MessageAttachmentMediaType;
        bookmarkedOnly: boolean;
        from?: UserId;
        timeFrame?: {
            start: number;
            end: number;
            limit?: number;
        };
        boundaries?: {
            dateMark: number;
            lowerLimit: number;
            upperLimit: number;
        };
        searchString?: string;
        sortOrder: SortOrder;
    }): Promise<MessageAttachmentsSearchResult>;
    loadBookmarkedMessages(params: {
        chatId?: string;
        timeFrame?: {
            start: number;
            end: number;
            limit?: number;
        };
        boundaries?: {
            dateMark: number;
            lowerLimit: number;
            upperLimit: number;
        };
        sortOrder: SortOrder;
    }): Promise<LoadBookmarkedMessagesResult>;
    loadMessagesWithMentions(params: {
        chatId?: string;
        userTag: string;
        timeFrame?: {
            start: number;
            end: number;
            limit?: number;
        };
        boundaries?: {
            dateMark: number;
            lowerLimit: number;
            upperLimit: number;
        };
        sortOrder: SortOrder;
    }): Promise<LoadMessagesWithMentionsResult>;
    createChat(chat: {
        id?: string;
        name?: string;
        members?: Array<UserId>;
        favourite?: boolean;
        channel?: boolean;
        type?: ChatType;
        channelSendPolicy?: ChannelSendPolicy;
        sendPermissionList?: Array<string>;
        allowedToAddExternalUser?: boolean;
    }): Promise<UserSpecificChatInfo>;
    deleteChat(chat: {
        id: string;
    }): Promise<void>;
    renameChat(chat: {
        id: string;
        name: string;
    }): Promise<void>;
    editChatMessage(msg: {
        chatId: string;
        messageId: string;
        body: string;
        attachmentsToSend?: Array<MessageAttachment>;
        attachmentIdsToDelete?: number[];
    }): Promise<MessageStatus>;
    deleteChatMessage(msg: {
        chatId: string;
        messageId: string;
    }): Promise<MessageStatus>;
    addMessageToBookmarks(msg: {
        chatId: string;
        messageId: string;
    }): Promise<void>;
    removeMessageFromBookmarks(msg: {
        chatId: string;
        messageId: string;
    }): Promise<void>;
    addMemberToChat(chat: {
        id: string;
        member: UserId;
    }): Promise<UserSpecificChatInfo>;
    removeMemberFromChat(chat: {
        id: string;
        member: UserId;
    }): Promise<UserSpecificChatInfo>;
    inviteContact(invite: {
        to: UserId | UserEmail;
    }): Promise<User>;
    addContactToFavourites(contact: {
        id: UserId;
    }): Promise<User>;
    removeContactFromFavourites(contact: {
        id: UserId;
    }): Promise<User>;
    confirmContact(invite: {
        id: string;
        from: UserId;
        to: UserId;
    }): Promise<User>;
    removeContact(contact: {
        id: UserId;
    }): Promise<User>;
    updateChannelSendPolicy(channel: {
        id: string;
        channelSendPolicy: ChannelSendPolicy;
    }): Promise<UserSpecificChatInfo>;
    updateChatReceivePolicy(channel: {
        id: string;
        chatReceivePolicy: ChatReceivePolicy;
    }): Promise<UserSpecificChatInfo>;
    addChannelSendPermissionListMember(channel: {
        id: string;
        member: UserId;
    }): Promise<UserSpecificChatInfo>;
    removeChannelSendPermissionListMember(channel: {
        id: string;
        member: UserId;
    }): Promise<UserSpecificChatInfo>;
    updateChatConfiguration(chat: {
        id: string;
        type?: ChatType;
        channelSendPolicy?: ChannelSendPolicy;
        sendPermissionList?: Array<string>;
        allowedToAddExternalUser?: boolean;
    }): Promise<UserSpecificChatInfo>;
    addChatToFavourites(chat: {
        id: string;
    }): Promise<UserSpecificChatInfo>;
    removeChatFromFavourites(chat: {
        id: string;
    }): Promise<UserSpecificChatInfo>;
    createRoom(options: {
        name?: string;
        pin?: string;
        id?: string;
    }): Promise<RoomExtended>;
    createRoomFromEvent(event: {
        id: string;
        title: string;
        description: string;
        start: number;
        end: number;
        recurring: boolean;
        accessCode?: string;
        waitingRoom: boolean;
        usePMI: boolean;
        ownerVideo: boolean;
        participantVideo: boolean;
        allowJoinAtAnyTime: boolean;
        useMuteAudioOnJoin: boolean;
        useLocalAutoRecord: boolean;
    }): Promise<RoomExtended>;
    loadActiveRooms(): Promise<RoomInfo[]>;
    roomAvailable(options: {
        id: string;
        pin?: string;
        nickname?: string;
    }): Promise<RoomExtended>;
    roomExists(options: {
        id: string;
        pin?: string;
    }): Promise<void>;
    getRoom(options: {
        id: string;
    }): RoomExtended;
    disconnect(): Promise<void>;
    user(): {
        username: string;
        email: string;
        nickname: string;
        pmi: string;
    };
    server(): string;
    state(): State;
    on(event: SfuEvent, callback: (arg0: NotifyUnion) => void): SfuExtended;
    off(event: SfuEvent, callback: (arg0: NotifyUnion) => void): SfuExtended;
    private closePcAndFireEvent;
}
export {};
